==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/Pip.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Manages dependencies using a requirements.txt file and the pip CLI tool.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.895Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Pip")
public class Pip extends io.github.cdklabs.projen.Component implements io.github.cdklabs.projen.python.IPythonDeps {

    protected Pip(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Pip(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param _options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pip(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.PipOptions _options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), _options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pip(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Adds a runtime dependency.
     * <p>
     * @param spec Format `<module>@<semver>`. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Adds a dev dependency.
     * <p>
     * @param spec Format `<module>@<semver>`. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addDevDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Installs dependencies (called during post-synthesis).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void installDependencies() {
        software.amazon.jsii.Kernel.call(this, "installDependencies", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A task that installs and updates dependencies.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask() {
        return software.amazon.jsii.Kernel.get(this, "installTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Pip}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Pip> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.python.PythonProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.python.PythonProject project;
        private io.github.cdklabs.projen.python.PipOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.python.PythonProject project) {
            this.project = project;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.python.Pip}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Pip build() {
            return new io.github.cdklabs.projen.python.Pip(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.PipOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.PipOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/Pip.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Manages dependencies using a requirements.txt file and the pip CLI tool.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.567Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Pip")
public class Pip extends io.github.cdklabs.projen.Component implements io.github.cdklabs.projen.python.IPythonDeps {

    protected Pip(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Pip(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param _options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pip(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.PipOptions _options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), _options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pip(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Adds a runtime dependency.
     * <p>
     * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Adds a dev dependency.
     * <p>
     * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addDevDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Installs dependencies (called during post-synthesis).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void installDependencies() {
        software.amazon.jsii.Kernel.call(this, "installDependencies", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A task that installs and updates dependencies.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask() {
        return software.amazon.jsii.Kernel.get(this, "installTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Pip}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Pip> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.python.PipOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.python.Pip}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Pip build() {
            return new io.github.cdklabs.projen.python.Pip(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.PipOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.PipOptions.Builder();
            }
            return this.options;
        }
    }
}
